try:
    import struct
except ImportError:
    import ustruct as struct
import requests
import time
import threading
import serial
import datetime
import os
import sys
import signal
import RPi.GPIO as GPIO
import re
from practicum import find_mcu_boards, McuBoard, PeriBoard
from Display import Display
devs = find_mcu_boards()
mcu = McuBoard(devs[0])
peri = PeriBoard(mcu)
display = Display()
display.init()
display.setup()
display.addfont('Minecraft.ttf', 8)
display.addfont('Pixeboy.ttf',20)
display.typeText(16,5,"Now Loading ...",display.fonts[1])
display.show()
time.sleep(2)
GPIO.setwarnings(False)
GPIO.setmode(GPIO.BCM)
GPIO.setup(4, GPIO.OUT)
uart = serial.Serial("/dev/ttyS0", baudrate=9600, timeout=0.25)
buffer = []
pm25_standard = 0
pm10_standard = 0
pm100_standard = 0
date = datetime.datetime.now()
currentdate = date.strftime("%x")
def read():
    while True:
        data = uart.read(32)  # read up to 32 bytes
        data = list(data)
        # print("read: ", data)          # this is a bytearray type
        global buffer
        buffer += data
        while buffer and buffer[0] != 0x42:
            buffer.pop(0)
        if len(buffer) > 200:
            buffer = []  # avoid an overrun if all bad data
        if len(buffer) < 32:
            continue
        if buffer[1] != 0x4d:
            buffer.pop(0)
            continue
        frame_len = struct.unpack(">H", bytes(buffer[2:4]))[0]
        if frame_len != 28:
            buffer = []
            continue
        global pm25_standard
        global pm10_standard
        global pm100_standard
        frame = struct.unpack(">HHHHHHHHHHHHHH", bytes(buffer[4:]))
        pm10_standard, pm25_standard, pm100_standard, pm10_env, \
            pm25_env, pm100_env, particles_03um, particles_05um, particles_10um, \
            particles_25um, particles_50um, particles_100um, skip, checksum = frame
        check = sum(buffer[0:30])
        if check != checksum:
            buffer = []
            continue
        print("Concentration Units (standard)")
        print("---------------------------------------")
        print("PM 1.0: %d\tPM2.5: %d\tPM10: %d" %
          (pm10_standard, pm25_standard, pm100_standard))
        print("Concentration Units (environmental)")
        print("---------------------------------------")
        print("PM 1.0: %d\tPM2.5: %d\tPM10: %d" % (pm10_env, pm25_env, pm100_env))
        print("---------------------------------------")
        print("Particles > 0.3um / 0.1L air:", particles_03um)
        print("Particles > 0.5um / 0.1L air:", particles_05um)
        print("Particles > 1.0um / 0.1L air:", particles_10um)
        print("Particles > 2.5um / 0.1L air:", particles_25um)
        print("Particles > 5.0um / 0.1L air:", particles_50um)
        print("Particles > 10 um / 0.1L air:", particles_100um)
        print("---------------------------------------")
        buffer = buffer[32:]
        display.setup()
        display.typeText(10,0,"PM TODAY",display.fonts[1])
        display.typeText(20,15,currentdate,display.fonts[0])
        display.typeText(80,0," PM1.0  " + str(pm10_standard),display.fonts[0])
        display.typeText(80,8," PM2.5  " + str(pm25_standard),display.fonts[0])
        display.typeText(80,16," PM10   " + str(pm100_standard),display.fonts[0])
        display.show()
        if int(pm25_standard) < 29:
            peri.set_led(2,1)
            peri.set_led(1,0)
            peri.set_led(0,0)
            GPIO.output(4,False)
        elif int(pm25_standard) < 40:
            peri.set_led(1,1)
            peri.set_led(2,0)
            peri.set_led(0,0)
            GPIO.output(4,False)
        else:
            peri.set_led(0,1)
            peri.set_led(1,0)
            peri.set_led(2,0)
            GPIO.output(4,False)
        time.sleep(1)
def request():
    while True:
        time.sleep(2)
        global pm10_standard
        global pm100_standard
        global pm25_standard
        requests.put('http://192.168.43.158:3000/dust_value',{'pm10':pm10_standard,'pm25':pm25_standard,'pm100':pm100_standard})
t1 = threading.Thread(target=read, args=())
t2 = threading.Thread(target=request, args=())
t1.start()
t2.start()
t1.join()
t2.join()
